# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`vault`](#vault): Issue and renew PKI certificates from Hashicorp Vault
* [`vault::vault_cert`](#vaultvault_cert): Manage paths and files for Vault certificates

### Resource types

* [`vault_cert`](#vault_cert): A type representing a certificate issued by Hashicorp Vault

### Functions

* [`vault_cert`](#vault_cert): Obtain a host certificate from a Vault PKI secrets engine
* [`vault_hash`](#vault_hash): Return a hash from a Vault key/value secrets engine path
* [`vault_hiera_hash`](#vault_hiera_hash): Custom hiera back-end for Hashicorp Vault key/value secrets engine
* [`vault_key`](#vault_key): Return the value from a Vault key/value secrets engine from a given path and key

## Classes

### `vault`

Issue and renew PKI certificates from Hashicorp Vault

#### Examples

##### Issue a host certificate from a Vault server with PKI secrets engine

```puppet
class { 'vault_secrets':
  vault_uri  => 'https://vault.example.com:8200/v1/pki/issue/example-com',
  auth_path  => 'puppet-pki',
}
```

#### Parameters

The following parameters are available in the `vault` class.

##### `vault_uri`

Data type: `String`

The complete URL of the the Hashicorp Vault certificate issuing role API endpoint

##### `auth_path`

Data type: `String`

The Vault path of the authentication provider used by Puppet certificates

##### `days_before_renewal`

Data type: `Integer[1, 30]`

The number of days before expiration where the host certificate will be re-issued

Default value: `3`

##### `cert_data`

Data type: `Hash`

A hash of values to be submitted with the certificate request.  The hash contents should
adhere to the keys/values supported/permitted by the PKI role and policy.  Basic default values are
defined in module hiera.

Default value: `{}`

### `vault::vault_cert`

Manage paths and files for Vault certificates

#### Parameters

The following parameters are available in the `vault::vault_cert` class.

##### `purge`

Data type: `Any`

Clean up certificate files no longer managed by puppet.

Default value: ``false``

## Resource types

### `vault_cert`

A type representing a certificate issued by Hashicorp Vault

#### Properties

The following properties are available in the `vault_cert` type.

##### `ca_chain`

Valid values: `auto`

Read-only property which contains the value of the CA chain

Default value: `auto`

##### `ca_chain_file`

Where the CA chain file should be written

##### `ca_chain_group`

The group which the ca_chain_file should be owned by

Default value: `root`

##### `ca_chain_mode`

The file mode the ca_chain_file should be written with

Default value: `0644`

##### `ca_chain_owner`

The user which the ca_chain_file should be owned by

Default value: `root`

##### `cert`

Valid values: `auto`

Read-only property which contains the value of the certificate

Default value: `auto`

##### `cert_data`

The attributes of the certificate to be issued

##### `cert_file`

Where the certificate file should be written

##### `cert_group`

The group which the cert_file should be owned by

Default value: `root`

##### `cert_mode`

The file mode the cert _file should be written with

Default value: `0644`

##### `cert_owner`

The user which the cert_file should be owned by

Default value: `root`

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `expiration`

Valid values: `auto`

Read-only property showing the expiration time of the certificate

Default value: `auto`

##### `info_ca_chain`

Valid values: `auto`

Read-only property which contains the value of the CA chain from the info file

Default value: `auto`

##### `info_cert`

Valid values: `auto`

Read-only property which contains the value of the cerificate from the info file

Default value: `auto`

##### `info_group`

The group which the info_file should be owned by

Default value: `root`

##### `info_key`

Valid values: `auto`

Read-only property which contains the value of the private key from the info file

Default value: `auto`

##### `info_mode`

The file mode the info_file should be written with

Default value: `0600`

##### `info_owner`

The user which the info_file should be owned by

Default value: `root`

##### `key`

Valid values: `auto`

Read-only property which contains the value of the privat ekey

Default value: `auto`

##### `key_file`

Where the key file should be written

##### `key_group`

The group which the key_file should be owned by

Default value: `root`

##### `key_mode`

The file mode the key file should be written with

Default value: `0600`

##### `key_owner`

The user which the key_file should be owned by

Default value: `root`

#### Parameters

The following parameters are available in the `vault_cert` type.

##### `auth_path`

The path used to authenticate puppet agent to vault

Default value: `puppet-pki`

##### `name`

namevar

The name of the certificate

##### `provider`

The specific backend to use for this `vault_cert` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### `renewal_threshold`

Certificate should be renewed when fewer than this many days remain before expiry

Default value: `3`

##### `timeout`

Length of time to wait on vault connections

Default value: `5`

##### `vault_uri`

The full URI of the vault PKI secrets engine

## Functions

### `vault_cert`

Type: Ruby 4.x API

Obtain a host certificate from a Vault PKI secrets engine

#### `vault_cert(String $vault_uri, String $auth_path, Hash $data, Optional[Integer] $timeout)`

The vault_cert function.

Returns: `Hash` The returned hash contains the certificate, private key, and supporting data

##### `vault_uri`

Data type: `String`

The complete API path to a Vault PKI role for issuing certificates.

##### `auth_path`

Data type: `String`

The Vault mount path of the "cert" authentication type used with Puppet certificates.

##### `data`

Data type: `Hash`

A hash of values to be submitted with a certificate request.  The hash contents
must adhere to the constructs of the Vault PKI role and policy being used at the 'vault_uri' endpoint.

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for Vault connections.  Default is 5.

### `vault_hash`

Type: Ruby 4.x API

Return a hash from a Vault key/value secrets engine path

#### `vault_hash(String $vault_uri, String $auth_path, Optional[String] $version, Optional[Integer] $timeout)`

The vault_hash function.

Returns: `Hash` Contains all the key/value pairs from the given path.

##### `vault_uri`

Data type: `String`

The full URI to the Vault API endpoint for a key/value secrets engine path.

##### `auth_path`

Data type: `String`

The Vault mount path of the 'cert' authentication type used with Puppet certificates.

##### `version`

Data type: `Optional[String]`

Set this value to 'v2' to use version 2 of the Vault key/value secrets engine.

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for Vault connections.

### `vault_hiera_hash`

Type: Ruby 4.x API

Custom hiera back-end for Hashicorp Vault key/value secrets engine

#### `vault_hiera_hash(Hash $options, Puppet::LookupContext $context)`

The vault_hiera_hash function.

Returns: `Hash` All key/value pairs from the given Vault path will be returned to hiera

##### `options`

Data type: `Hash`

Hash containing:

##### `context`

Data type: `Puppet::LookupContext`

Default parameter used for caching

### `vault_key`

Type: Ruby 4.x API

Return the value from a Vault key/value secrets engine from a given path and key

#### `vault_key(String $vault_uri, String $auth_path, String $key, Optional[String] $version, Optional[Integer] $timeout)`

The vault_key function.

Returns: `String` The value of the secret from the @vault_uri and @key

##### `vault_uri`

Data type: `String`

The complete API path to a Vault key/value secret

##### `auth_path`

Data type: `String`

The Vault mount path of the "cert" authentication type used with Puppet certificates.

##### `key`

Data type: `String`

The name of a specific secret at the given 'vault_uri'

##### `version`

Data type: `Optional[String]`

Set this value to 'v2' to use version 2 of the Vault key/value secrets engine

##### `timeout`

Data type: `Optional[Integer]`

Value in seconds to wait for a response from Vault

